@@ -19,13 +19,14 @@ package eventlistener
 import (
 	"context"
 	"fmt"
+	"os"
 	"strconv"
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
-	"github.com/tektoncd/pipeline/pkg/system"
 	"github.com/tektoncd/triggers/pkg/apis/triggers/v1alpha1"
+	"github.com/tektoncd/triggers/pkg/system"
 	"github.com/tektoncd/triggers/test"
 	bldr "github.com/tektoncd/triggers/test/builder"
 	appsv1 "k8s.io/api/apps/v1"
@@ -49,6 +50,11 @@ func init() {
 	eventListener0 = bldr.EventListener(eventListenerName, namespace,
 		bldr.EventListenerSpec(
 			bldr.EventListenerServiceAccount("sa"),
+			bldr.EventListenerPodTemplate(
+				bldr.EventListenerPodTemplateSpec(
+					bldr.EventListenerPodTemplateTolerations(nil),
+				),
+			),
 		),
 		bldr.EventListenerStatus(
 			bldr.EventListenerConfig(generatedResourceName),
@@ -61,17 +67,31 @@ var (
 	ignoreLastTransitionTime = cmpopts.IgnoreTypes(apis.Condition{}.LastTransitionTime.Inner.Time)
 
 	// 0 indicates pre-reconciliation
-	eventListener0    *v1alpha1.EventListener
-	eventListenerName = "my-eventlistener"
-	namespace         = "tekton-pipelines"
-	namespaceResource = &corev1.Namespace{
+	eventListener0      *v1alpha1.EventListener
+	eventListenerName   = "my-eventlistener"
+	namespace           = "test-pipelines"
+	reconcilerNamespace = "tekton-pipelines"
+	namespaceResource   = &corev1.Namespace{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: namespace,
 		},
 	}
-	reconcileKey                 = fmt.Sprintf("%s/%s", namespace, eventListenerName)
-	updateLabel                  = map[string]string{"update": "true"}
-	updatedSa                    = "updatedSa"
+	reconcilerNamespaceResource = &corev1.Namespace{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: reconcilerNamespace,
+		},
+	}
+	reconcileKey      = fmt.Sprintf("%s/%s", namespace, eventListenerName)
+	updateLabel       = map[string]string{"update": "true"}
+	updatedSa         = "updatedSa"
+	updateTolerations = []corev1.Toleration{
+		{
+			Key:      "key",
+			Operator: "Equal",
+			Value:    "value",
+			Effect:   "NoSchedule",
+		},
+	}
 	deploymentAvailableCondition = appsv1.DeploymentCondition{
 		Type:    appsv1.DeploymentAvailable,
 		Status:  corev1.ConditionTrue,
@@ -259,6 +279,9 @@ func Test_reconcileDeployment(t *testing.T) {
 	eventListener4 := eventListener1.DeepCopy()
 	eventListener4.Spec.ServiceAccountName = updatedSa
 
+	eventListener5 := eventListener1.DeepCopy()
+	eventListener5.Spec.PodTemplate.Tolerations = updateTolerations
+
 	var replicas int32 = 1
 	// deployment1 == initial deployment
 	deployment1 := &appsv1.Deployment{
@@ -273,6 +296,7 @@ func Test_reconcileDeployment(t *testing.T) {
 					Labels: generatedLabels,
 				},
 				Spec: corev1.PodSpec{
+					Tolerations:        eventListener0.Spec.PodTemplate.Tolerations,
 					ServiceAccountName: eventListener0.Spec.ServiceAccountName,
 					Containers: []corev1.Container{
 						{
@@ -295,6 +319,17 @@ func Test_reconcileDeployment(t *testing.T) {
 								PeriodSeconds:    int32(*PeriodSeconds),
 								FailureThreshold: int32(*FailureThreshold),
 							},
+							ReadinessProbe: &corev1.Probe{
+								Handler: corev1.Handler{
+									HTTPGet: &corev1.HTTPGetAction{
+										Path:   "/live",
+										Scheme: corev1.URISchemeHTTP,
+										Port:   intstr.FromInt((*ElPort)),
+									},
+								},
+								PeriodSeconds:    int32(*PeriodSeconds),
+								FailureThreshold: int32(*FailureThreshold),
+							},
 							Args: []string{
 								"-el-name", eventListenerName,
 								"-el-namespace", namespace,
@@ -355,6 +390,9 @@ func Test_reconcileDeployment(t *testing.T) {
 	deployment4 := deployment1.DeepCopy()
 	deployment4.Spec.Template.Spec.ServiceAccountName = updatedSa
 
+	deployment5 := deployment1.DeepCopy()
+	deployment5.Spec.Template.Spec.Tolerations = updateTolerations
+
 	deploymentMissingVolumes := deployment1.DeepCopy()
 	deploymentMissingVolumes.Spec.Template.Spec.Volumes = nil
 	deploymentMissingVolumes.Spec.Template.Spec.Containers[0].VolumeMounts = nil
@@ -440,7 +478,21 @@ func Test_reconcileDeployment(t *testing.T) {
 				EventListeners: []*v1alpha1.EventListener{eventListener4},
 				Deployments:    []*appsv1.Deployment{deployment4},
 			},
-		}, {
+		},
+		{
+			name: "eventlistener-tolerations-update",
+			startResources: test.Resources{
+				Namespaces:     []*corev1.Namespace{namespaceResource},
+				EventListeners: []*v1alpha1.EventListener{eventListener5},
+				Deployments:    []*appsv1.Deployment{deployment1},
+			},
+			endResources: test.Resources{
+				Namespaces:     []*corev1.Namespace{namespaceResource},
+				EventListeners: []*v1alpha1.EventListener{eventListener5},
+				Deployments:    []*appsv1.Deployment{deployment5},
+			},
+		},
+		{
 			name: "eventlistener-config-volume-mount-update",
 			startResources: test.Resources{
 				Namespaces:     []*corev1.Namespace{namespaceResource},
@@ -490,9 +542,15 @@ func Test_reconcileDeployment(t *testing.T) {
 }
 
 func TestReconcile(t *testing.T) {
+	os.Setenv("SYSTEM_NAMESPACE", "tekton-pipelines")
 	eventListener1 := bldr.EventListener(eventListenerName, namespace,
 		bldr.EventListenerSpec(
 			bldr.EventListenerServiceAccount("sa"),
+			bldr.EventListenerPodTemplate(
+				bldr.EventListenerPodTemplateSpec(
+					bldr.EventListenerPodTemplateTolerations(nil),
+				),
+			),
 		),
 		bldr.EventListenerStatus(
 			bldr.EventListenerConfig(generatedResourceName),
@@ -531,6 +589,9 @@ func TestReconcile(t *testing.T) {
 	eventListener4 := eventListener3.DeepCopy()
 	eventListener4.Spec.ServiceType = corev1.ServiceTypeNodePort
 
+	eventListener5 := eventListener2.DeepCopy()
+	eventListener5.Spec.PodTemplate.Tolerations = updateTolerations
+
 	var replicas int32 = 1
 	deployment1 := &appsv1.Deployment{
 		ObjectMeta: generateObjectMeta(eventListener0),
@@ -544,6 +605,7 @@ func TestReconcile(t *testing.T) {
 					Labels: generatedLabels,
 				},
 				Spec: corev1.PodSpec{
+					Tolerations:        eventListener0.Spec.PodTemplate.Tolerations,
 					ServiceAccountName: eventListener0.Spec.ServiceAccountName,
 					Containers: []corev1.Container{{
 						Name:  "event-listener",
@@ -563,6 +625,17 @@ func TestReconcile(t *testing.T) {
 							PeriodSeconds:    int32(*PeriodSeconds),
 							FailureThreshold: int32(*FailureThreshold),
 						},
+						ReadinessProbe: &corev1.Probe{
+							Handler: corev1.Handler{
+								HTTPGet: &corev1.HTTPGetAction{
+									Path:   "/live",
+									Scheme: corev1.URISchemeHTTP,
+									Port:   intstr.FromInt((*ElPort)),
+								},
+							},
+							PeriodSeconds:    int32(*PeriodSeconds),
+							FailureThreshold: int32(*FailureThreshold),
+						},
 						Args: []string{
 							"-el-name", eventListenerName,
 							"-el-namespace", namespace,
@@ -610,6 +683,9 @@ func TestReconcile(t *testing.T) {
 	deployment3 := deployment2.DeepCopy()
 	deployment3.Spec.Template.Spec.ServiceAccountName = updatedSa
 
+	deployment4 := deployment2.DeepCopy()
+	deployment4.Spec.Template.Spec.Tolerations = updateTolerations
+
 	service1 := &corev1.Service{
 		ObjectMeta: generateObjectMeta(eventListener0),
 		Spec: corev1.ServiceSpec{
@@ -637,6 +713,8 @@ func TestReconcile(t *testing.T) {
 
 	loggingConfigMap := defaultLoggingConfigMap()
 	loggingConfigMap.ObjectMeta.Namespace = namespace
+	reconcilerLoggingConfigMap := defaultLoggingConfigMap()
+	reconcilerLoggingConfigMap.ObjectMeta.Namespace = reconcilerNamespace
 
 	tests := []struct {
 		name           string
@@ -693,6 +771,22 @@ func TestReconcile(t *testing.T) {
 			Services:       []*corev1.Service{service2},
 			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
 		},
+	}, {
+		name: "update-eventlistener-tolerations",
+		key:  reconcileKey,
+		startResources: test.Resources{
+			Namespaces:     []*corev1.Namespace{namespaceResource},
+			EventListeners: []*v1alpha1.EventListener{eventListener5},
+			Deployments:    []*appsv1.Deployment{deployment2},
+			Services:       []*corev1.Service{service2},
+		},
+		endResources: test.Resources{
+			Namespaces:     []*corev1.Namespace{namespaceResource},
+			EventListeners: []*v1alpha1.EventListener{eventListener5},
+			Deployments:    []*appsv1.Deployment{deployment4},
+			Services:       []*corev1.Service{service2},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+		},
 	}, {
 		name: "update-eventlistener-servicetype",
 		key:  reconcileKey,
@@ -724,6 +818,17 @@ func TestReconcile(t *testing.T) {
 		endResources: test.Resources{
 			Namespaces: []*corev1.Namespace{namespaceResource},
 		},
+	}, {
+		name: "delete-last-eventlistener-in-our-namespace",
+		key:  fmt.Sprintf("%s/%s", reconcilerNamespace, eventListenerName),
+		startResources: test.Resources{
+			Namespaces: []*corev1.Namespace{reconcilerNamespaceResource},
+			ConfigMaps: []*corev1.ConfigMap{reconcilerLoggingConfigMap},
+		},
+		endResources: test.Resources{
+			Namespaces: []*corev1.Namespace{reconcilerNamespaceResource},
+			ConfigMaps: []*corev1.ConfigMap{reconcilerLoggingConfigMap},
+		},
 	}, {
 		name: "delete-eventlistener-with-remaining-eventlistener",
 		key:  reconcileKey,
@@ -746,7 +851,6 @@ func TestReconcile(t *testing.T) {
 			// Setup with startResources
 			testAssets, cancel := getEventListenerTestAssets(t, tt.startResources)
 			defer cancel()
-
 			// Run Reconcile
 			err := testAssets.Controller.Reconciler.Reconcile(context.Background(), tt.key)
 			if err != nil {
