@@ -39,8 +39,9 @@ import (
 
 	"github.com/gorilla/mux"
 	pipelinev1alpha1 "github.com/tektoncd/pipeline/pkg/apis/pipeline/v1alpha1"
+	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1beta1"
 	pipelinev1 "github.com/tektoncd/pipeline/pkg/apis/pipeline/v1beta1"
-	"github.com/tektoncd/pipeline/pkg/logging"
+	"github.com/tektoncd/triggers/pkg/apis/triggers/v1alpha1"
 	triggersv1 "github.com/tektoncd/triggers/pkg/apis/triggers/v1alpha1"
 	dynamicclientset "github.com/tektoncd/triggers/pkg/client/dynamic/clientset"
 	"github.com/tektoncd/triggers/pkg/client/dynamic/clientset/tekton"
@@ -86,7 +87,8 @@ func getSinkAssets(t *testing.T, resources test.Resources, elName string, auth A
 	clients := test.SeedResources(t, ctx, resources)
 	test.AddTektonResources(clients.Kube)
 
-	logger, _ := logging.NewLogger("", "")
+	logger, _ := zap.NewProduction()
+
 	dynamicClient := fakedynamic.NewSimpleDynamicClient(runtime.NewScheme())
 	dynamicSet := dynamicclientset.New(tekton.WithClient(dynamicClient))
 
@@ -97,7 +99,7 @@ func getSinkAssets(t *testing.T, resources test.Resources, elName string, auth A
 		DiscoveryClient:        clients.Kube.Discovery(),
 		KubeClientSet:          clients.Kube,
 		TriggersClient:         clients.Triggers,
-		Logger:                 logger,
+		Logger:                 logger.Sugar(),
 		Auth:                   auth,
 	}
 	return r, dynamicClient
@@ -151,7 +153,7 @@ func TestHandleEvent(t *testing.T) {
 			Kind:       "PipelineResource",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      "$(params.name)",
+			Name:      "$(tt.params.name)",
 			Namespace: namespace,
 			Labels: map[string]string{
 				"app":  "$(params.foo)",
@@ -196,7 +198,7 @@ func TestHandleEvent(t *testing.T) {
 		tbs = append(tbs, tb)
 		// Add TriggerBinding to trigger in EventListener
 		trigger := bldr.EventListenerTrigger("my-triggertemplate", "v1alpha1",
-			bldr.EventListenerTriggerBinding(tbName, "", "v1alpha1"),
+			bldr.EventListenerTriggerBinding(tbName, "", tbName, "v1alpha1"),
 		)
 		triggers = append(triggers, trigger)
 	}
@@ -271,7 +273,7 @@ func TestHandleEventWithInterceptors(t *testing.T) {
 			Type: pipelinev1alpha1.PipelineResourceTypeGit,
 			Params: []pipelinev1alpha1.ResourceParam{{
 				Name:  "url",
-				Value: "$(params.url)",
+				Value: "$(tt.params.url)",
 			}},
 		},
 	}
@@ -411,7 +413,7 @@ func TestHandleEventWithWebhookInterceptors(t *testing.T) {
 			Kind:       "PipelineResource",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      "$(params.name)",
+			Name:      "$(tt.params.name)",
 			Namespace: namespace,
 		},
 		Spec: pipelinev1alpha1.PipelineResourceSpec{
@@ -446,7 +448,13 @@ func TestHandleEventWithWebhookInterceptors(t *testing.T) {
 			Interceptors: []*triggersv1.EventInterceptor{{
 				Webhook: &triggersv1.WebhookInterceptor{
 					ObjectRef: interceptorObjectRef,
-					Header:    []pipelinev1alpha1.Param{bldr.Param("Name", fmt.Sprintf("my-resource-%d", i))},
+					Header: []v1beta1.Param{{
+						Name: "Name",
+						Value: v1beta1.ArrayOrString{
+							Type:      v1beta1.ParamTypeString,
+							StringVal: fmt.Sprintf("my-resource-%d", i),
+						},
+					}},
 				},
 			}},
 		}
@@ -555,10 +563,11 @@ func TestExecuteInterceptor(t *testing.T) {
 		Proxy: http.ProxyURL(u),
 	}
 
-	logger, _ := logging.NewLogger("", "")
+	logger, _ := zap.NewProduction()
+
 	r := Sink{
 		HTTPClient: srv.Client(),
-		Logger:     logger,
+		Logger:     logger.Sugar(),
 	}
 
 	a := &triggersv1.EventInterceptor{
@@ -590,7 +599,7 @@ func TestExecuteInterceptor(t *testing.T) {
 			if err != nil {
 				t.Fatalf("http.NewRequest: %v", err)
 			}
-			resp, header, err := r.executeInterceptors(trigger, req, []byte(`{}`), logger)
+			resp, header, err := r.executeInterceptors(trigger, req, []byte(`{}`), logger.Sugar())
 			if err != nil {
 				t.Fatalf("executeInterceptors: %v", err)
 			}
@@ -638,10 +647,10 @@ func TestExecuteInterceptor_error(t *testing.T) {
 		Proxy: http.ProxyURL(u),
 	}
 
-	logger, _ := logging.NewLogger("", "")
+	logger, _ := zap.NewProduction()
 	s := Sink{
 		HTTPClient: client,
-		Logger:     logger,
+		Logger:     logger.Sugar(),
 	}
 
 	trigger := &triggersv1.EventListenerTrigger{
@@ -671,7 +680,7 @@ func TestExecuteInterceptor_error(t *testing.T) {
 	if err != nil {
 		t.Fatalf("http.NewRequest: %v", err)
 	}
-	if resp, _, err := s.executeInterceptors(trigger, req, nil, logger); err == nil {
+	if resp, _, err := s.executeInterceptors(trigger, req, nil, logger.Sugar()); err == nil {
 		t.Errorf("expected error, got: %+v, %v", string(resp), err)
 	}
 
@@ -780,39 +789,7 @@ func TestHandleEventWithInterceptorsAndTriggerAuth(t *testing.T) {
 		},
 	} {
 		eventBody := json.RawMessage(`{"head_commit": {"id": "testrevision"}, "repository": {"url": "testurl"}, "foo": "bar\t\r\nbaz昨"}`)
-
-		pipelineResource := pipelinev1alpha1.PipelineResource{
-			TypeMeta: metav1.TypeMeta{
-				APIVersion: "tekton.dev/v1alpha1",
-				Kind:       "PipelineResource",
-			},
-			ObjectMeta: metav1.ObjectMeta{
-				Name:      "my-pipelineresource",
-				Namespace: namespace,
-			},
-			Spec: pipelinev1alpha1.PipelineResourceSpec{
-				Type: pipelinev1.PipelineResourceTypeGit,
-				Params: []pipelinev1.ResourceParam{{
-					Name:  "url",
-					Value: "$(params.url)",
-				}},
-			},
-		}
-		pipelineResourceBytes, err := json.Marshal(pipelineResource)
-		if err != nil {
-			t.Fatalf("Error unmarshalling pipelineResource: %s", err)
-		}
-
-		tt := bldr.TriggerTemplate("tt", namespace,
-			bldr.TriggerTemplateSpec(
-				bldr.TriggerTemplateParam("url", "", ""),
-				bldr.TriggerResourceTemplate(runtime.RawExtension{Raw: pipelineResourceBytes}),
-			))
-		tb := bldr.TriggerBinding("tb", namespace,
-			bldr.TriggerBindingSpec(
-				bldr.TriggerBindingParam("url", "$(body.repository.url)"),
-			))
-
+		tb, tt := getResources(t, "$(body.repository.url)")
 		authSecret := &corev1.Secret{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      testCase.userVal,
@@ -920,3 +897,128 @@ func TestHandleEventWithInterceptorsAndTriggerAuth(t *testing.T) {
 	}
 
 }
+
+func TestHandleEventWithBitbucketInterceptors(t *testing.T) {
+	eventBody := json.RawMessage(`{"repository": {"links": {"clone": [{"href": "testurl", "name": "ssh"}, {"href": "testurl", "name": "http"}]}}, "changes": [{"ref": {"displayId": "test-branch"}}]}`)
+	tb, tt := getResources(t, "$(body.repository.links.clone[1].href)")
+
+	authSA := &corev1.ServiceAccount{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      userWithPermissions,
+			Namespace: userWithPermissions,
+			UID:       types.UID(userWithPermissions),
+		},
+	}
+
+	el := &triggersv1.EventListener{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "el",
+			Namespace: namespace,
+		},
+		Spec: triggersv1.EventListenerSpec{
+			Triggers: []triggersv1.EventListenerTrigger{{
+				ServiceAccount: &corev1.ObjectReference{
+					Namespace: userWithPermissions,
+					Name:      userWithPermissions,
+				},
+				Bindings: []*triggersv1.EventListenerBinding{{Name: "tb", Kind: "TriggerBinding"}},
+				Template: triggersv1.EventListenerTemplate{Name: "tt"},
+				Interceptors: []*triggersv1.EventInterceptor{{
+					Bitbucket: &triggersv1.BitbucketInterceptor{
+						SecretRef: &triggersv1.SecretRef{
+							SecretKey:  "secretKey",
+							SecretName: "secret",
+							Namespace:  namespace,
+						},
+						EventTypes: []string{"repo:refs_changed"},
+					},
+				}},
+			}},
+		},
+	}
+	secret := &corev1.Secret{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "secret",
+			Namespace: namespace,
+		},
+		Data: map[string][]byte{
+			"secretKey": []byte("secret"),
+		},
+	}
+
+	resources := test.Resources{
+		TriggerBindings:  []*triggersv1.TriggerBinding{tb},
+		TriggerTemplates: []*triggersv1.TriggerTemplate{tt},
+		EventListeners:   []*triggersv1.EventListener{el},
+		Secrets:          []*corev1.Secret{secret},
+		ServiceAccounts:  []*corev1.ServiceAccount{authSA},
+	}
+	sink, dynamicClient := getSinkAssets(t, resources, el.Name, fakeAuth{})
+	ts := httptest.NewServer(http.HandlerFunc(sink.HandleEvent))
+	defer ts.Close()
+
+	triggerAuthWG.Add(1)
+
+	dynamicClient.PrependReactor("*", "*", func(action ktesting.Action) (handled bool, ret runtime.Object, err error) {
+		defer triggerAuthWG.Done()
+		return false, nil, nil
+	})
+
+	req, err := http.NewRequest("POST", ts.URL, bytes.NewReader(eventBody))
+	if err != nil {
+		t.Fatalf("Error creating Post request: %s", err)
+	}
+	req.Header.Add("X-Event-Key", "repo:refs_changed")
+	// This was generated by using SHA1 and hmac from go stdlib on secret and payload.
+	// https://play.golang.org/p/ovlZGxCP07E for a sample.
+	req.Header.Add("X-Hub-Signature", "sha1=efaa666dce82d7acd087779314c2f80eb3447102")
+
+	resp, err := http.DefaultClient.Do(req)
+	if err != nil {
+		t.Fatalf("Error sending Post request: %v", err)
+	}
+
+	if resp.StatusCode != http.StatusCreated {
+		t.Fatalf("Response code doesn't match: expected status code %d vs. actual %d, entire statutes %v",
+			http.StatusCreated,
+			resp.StatusCode,
+			resp.Status)
+	}
+}
+
+func getResources(t *testing.T, triggerBindingParam string) (*v1alpha1.TriggerBinding, *v1alpha1.TriggerTemplate) {
+	t.Helper()
+	pipelineResource := pipelinev1alpha1.PipelineResource{
+		TypeMeta: metav1.TypeMeta{
+			APIVersion: "tekton.dev/v1alpha1",
+			Kind:       "PipelineResource",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "my-pipelineresource",
+			Namespace: namespace,
+		},
+		Spec: pipelinev1alpha1.PipelineResourceSpec{
+			Type: pipelinev1.PipelineResourceTypeGit,
+			Params: []pipelinev1.ResourceParam{{
+				Name:  "url",
+				Value: "$(tt.params.url)",
+			}},
+		},
+	}
+	pipelineResourceBytes, err := json.Marshal(pipelineResource)
+	if err != nil {
+		t.Fatalf("Error unmarshalling pipelineResource: %s", err)
+	}
+
+	tt := bldr.TriggerTemplate("tt", namespace,
+		bldr.TriggerTemplateSpec(
+			bldr.TriggerTemplateParam("url", "", ""),
+			bldr.TriggerResourceTemplate(runtime.RawExtension{Raw: pipelineResourceBytes}),
+		))
+	tb := bldr.TriggerBinding("tb", namespace,
+		bldr.TriggerBindingSpec(
+			bldr.TriggerBindingParam("url", triggerBindingParam),
+		))
+
+	return tb, tt
+}
